#!/bin/bash

####################################################
# Traffic Mail Skript
# ---------------------------------------------
#
# Autor   : Dominique Kaspar <donkaspar@snooweatinganima.de>
# Version : 1.07
# Datum   : 20.11.2010
# Umgebung: Hostsharing Server
# Lizenz  : GPL2
#
# Auslesen des HTTP Logfiles im HS Format,
# anschliessender Versand via mail
#
# History:
# --------
#  1.07    dk     logfileauswertung an -iptables file angepasst
#  1.06    dk     Subject der eMail ohne Umlaut
#  1.05    dk     Monatsende abfangen (danke Christian Gnter fr die Anregung)
#  1.04    dk     quota -sg angefuegt
#  1.03    dk     Anpassung an neues Logfileformat
#  1.02    dk     Header X-Trafficmail angefuegt
#  1.01    dk     Auslesen des Gesamttraffics durch Bjoerns Skript
#  1.00    dk     Erste Version
#
#
# Aufruf:
# -------
# $ sh ~/skripts/tlog.sh
#
# # Hinweis:
# ========
#
# Die Variablen $user in 'tlog.sh' wie auch die Variable $httpfile in
# 'month-http-xfer.pl' mssen angepasst werden. Der Auf-
# ruf des Skripts erfolgt am sinnvollsten ber den Event-Handler
# '@weblogsplit' (siehe Beschreibung unter 
# http://www.hostsharing.net/tech/descriptions/more.htm#etc_event_handler)
#
# ToDo:
# -----
# - optionale Auswertung der domainspezifischen Trafficlogs
# 
# ----------------------------------------------

#####################################################
# Dieses Skript soll die Traffic-Logdatei in ~/var #
# formatmaessig etwas aufpolieren und an einen     #
# default-user verschicken.                        #
####################################################

# Hier kann man den Empfnger angeben

USER=MEINE@EMAILADRESSE.DE

# ber diese Variable wird die Logdatei angesprochen. Zudem wird der Grenzfall
# "letzter Tag des Monats" abgedeckt, in dem die Auswertung (ber den Eventhandler)
# erst im neuen Monat stattfindet, der Trafficlog aber im File des letzten Monats 
# liegt.

if [ $(date +%m) == $(date --date="yesterday" +%m) ]; then
   FILE=~/var/traffic-iptables-$(date +%Y)-$(date +%m).log
else
   FILE=~/var/traffic-iptables-$(date --date="yesterday" +%Y)-$(date --date="yesterday" +%m).log 
fi

# Diese Funktion gibt den jeweils tagesaktuellen Eintrag
# des allgemeinen Logfiles in einzelnen Lines wieder

function split
{
    COUNTER=0
    while [ $COUNTER -lt 9 ]; do
	let COUNTER=COUNTER+1
	tail -n1 $FILE |cut -d';' -f$COUNTER
    done
}

# Hier setzen wir die aktuellen Werte in Variablen
# DAT = Datum, PAK = Paketname, GTM = Gebuchter Traffic in MB pro Monat,
# GTT = (rechnerisch ermittelter) gebuchter Traffic pro Tag in MB, 
# STT = Summe des Gesamttraffics pro Tag in MB, IP1 = 1. IP Adresse,
# IP1TR = Traffic fuer IP1, IP2 = 2. IP Adresse, IP2TR = Traffic uer IP2

DAT=`split|sed -n '1p'` 
PAK=`split|sed -n '2p'`
GTM=`split|sed -n '3p'`
GTT=`split|sed -n '4p'`
STT=`split|sed -n '5p'`
IP1=`split|sed -n '6p'`
IP1TR=`split|sed -n '7p'`
IP2=`split|sed -n '8p'`
IP2TR=`split|sed -n '9p'`

###################################
# Zustzliche Auswertungen
###################################

# mit einem Perl Skript von Bjoern kann man den gesamten 
# bisherigen Traffic ausrechnen. Der wird im folgenden in der 
# Variable GTRF gespeichert. 

GTRF=`perl ~/skripts/month-http-xfer.pl`

# In QUOT speichern wir die Gruppenquota des Pakets

QUOT=`quota -sg`

###################################
# Mailversand an $USER
###################################

mail -a "X-Trafficmail: $DAT" -s "Traffic fuer $PAK vom $DAT" $USER <<EOT

Dies ist die Trafficmail fuer das Paket $PAK. 

Gebuchter Traffic pro Monat: $GTM MB (entspricht $GTT MB pro Tag)

Traffic am $DAT: $STT MB, davon:

$IP1TR MB auf der IP Adresse $IP1.

Gesamttraffic diesen Monat: $GTRF

$QUOT

EOT